@@ -1022,6 +1022,18 @@ STATIC void dcNsCompHwBlockPopulateGen4(
             (pService->comp_device_data.enableDmm == CPA_TRUE)
                 ? ICP_QAT_HW_COMP_20_EXTENDED_DELAY_MATCH_MODE_EDMM_ENABLED
                 : ICP_QAT_HW_COMP_20_EXTENDED_DELAY_MATCH_MODE_EDMM_DISABLED;
+        if ((pSetupData->huffType == CPA_DC_HT_FULL_DYNAMIC) &&
+            (pSetupData->compType == CPA_DC_DEFLATE) &&
+            (pSetupData->compLevel == CPA_DC_L10 ||
+             pSetupData->compLevel == CPA_DC_L11 ||
+             pSetupData->compLevel == CPA_DC_L12))
+        {
+            /* Enable Adaptive Block Drop with dynamic deflate
+             * compression when levels 10-12 are selected.
+             * This field is ignored by firmware for devices that
+             * do not support adaptive block drop */
+            hw_comp_lower_csr.abd = ICP_QAT_HW_COMP_20_ABD_ABD_ENABLED;
+        }
 
         /* Hard-coded HW-specific values */
         hw_comp_upper_csr.nice =
