@@ -568,45 +568,3 @@ CpaStatus Lac_MemPoolInitAsymCookies(lac_memory_pool_id_t poolID,
 #endif
 #endif
 
-CpaStatus Lac_MemPoolInitDcCookiePhyAddr(lac_memory_pool_id_t poolID)
-{
-    lac_mem_pool_hdr_t *pPoolID = (lac_mem_pool_hdr_t *)poolID;
-    dc_compression_cookie_t *pCookie = NULL;
-    lac_mem_blk_t *pCurrentBlk = NULL;
-
-    if (NULL == pPoolID)
-    {
-        LAC_LOG_ERROR("Invalid Pool ID");
-        return CPA_STATUS_FAIL;
-    }
-
-    if (NULL == pPoolID->trackBlks)
-    {
-        pCurrentBlk = top(&pPoolID->stack);
-
-        while (pCurrentBlk != NULL)
-        {
-            pCookie = (dc_compression_cookie_t *)((LAC_ARCH_UINT)(pCurrentBlk) +
-                                                  sizeof(lac_mem_blk_t));
-            pCurrentBlk = pCurrentBlk->pNext;
-
-            // pCookie->dcReqParamsBufferPhyAddr =
-            LAC_OS_VIRT_TO_PHYS_INTERNAL(pCookie->dcReqParamsBuffer);
-        }
-    }
-    else
-    {
-        Cpa32U count = 0;
-
-        for (count = 0; count < pPoolID->numElementsInPool; count++)
-        {
-            pCurrentBlk = pPoolID->trackBlks[count];
-            pCookie = (dc_compression_cookie_t *)((LAC_ARCH_UINT)(pCurrentBlk) +
-                                                  sizeof(lac_mem_blk_t));
-
-            // pCookie->dcReqParamsBufferPhyAddr =
-            LAC_OS_VIRT_TO_PHYS_INTERNAL(pCookie->dcReqParamsBuffer);
-        }
-    }
-    return CPA_STATUS_SUCCESS;
-}
