@@ -221,6 +221,20 @@ static Cpa8U dsa_3072_256_q[] = {
     0x3c, 0x9c, 0xb8, 0xa3, 0x06, 0xee, 0x25, 0x68, 0xdc, 0x22, 0x8c,
     0x4a, 0x39, 0x96, 0x01, 0xe3, 0x57, 0x93, 0xf4, 0x4e, 0x41};
 extern Cpa32U packageIdCount_g;
+void dsaGenRandom(CpaFlatBuffer *dsaRand, CpaFlatBuffer *dsaQ);
+CpaStatus dsaGenG(CpaInstanceHandle instanceHandle,
+                  CpaCyDsaGParamGenOpData *gOpData,
+                  CpaFlatBuffer *dsaG);
+CpaStatus dsaGenY(CpaInstanceHandle instanceHandle,
+                  CpaCyDsaYParamGenOpData *yOpData,
+                  CpaFlatBuffer *dsaY);
+CpaStatus dsaGenRS(CpaInstanceHandle instanceHandle,
+                   CpaCyDsaRSSignOpData *rsOpData,
+                   CpaFlatBuffer *dsaR,
+                   CpaFlatBuffer *dsaS);
+void dsaPerformance(single_thread_test_data_t *testSetup);
+CpaStatus dsaPerform(dsa_test_params_t *setup);
+void dsaSignPerformance(single_thread_test_data_t *testSetup);
 
 /**
  *****************************************************************************
@@ -733,20 +747,20 @@ CpaStatus dsaGenZ(CpaInstanceHandle instanceHandle,
  *      free all memory used in DSA performance code in this file
  *
  *****************************************************************************/
-void freeDsaMem(dsa_test_params_t *setup,
-                CpaFlatBuffer *dsaX,
-                CpaFlatBuffer *dsaY,
-                CpaFlatBuffer *dsaK,
-                CpaFlatBuffer *dsaM,
-                CpaFlatBuffer *dsaZ,
-                CpaFlatBuffer *dsaR,
-                CpaFlatBuffer *dsaS,
-                CpaCyDsaVerifyOpData *verifyOpData,
-                CpaCyDsaRSSignOpData *rsOpData,
-                CpaFlatBuffer dsaG,
-                CpaFlatBuffer dsaP,
-                CpaFlatBuffer dsaH,
-                CpaFlatBuffer dsaQ)
+static void freeDsaMem(dsa_test_params_t *setup,
+                       CpaFlatBuffer *dsaX,
+                       CpaFlatBuffer *dsaY,
+                       CpaFlatBuffer *dsaK,
+                       CpaFlatBuffer *dsaM,
+                       CpaFlatBuffer *dsaZ,
+                       CpaFlatBuffer *dsaR,
+                       CpaFlatBuffer *dsaS,
+                       CpaCyDsaVerifyOpData *verifyOpData,
+                       CpaCyDsaRSSignOpData *rsOpData,
+                       CpaFlatBuffer dsaG,
+                       CpaFlatBuffer dsaP,
+                       CpaFlatBuffer dsaH,
+                       CpaFlatBuffer dsaQ)
 {
     freeArrayFlatBufferNUMA(dsaX, setup->numBuffers);
     freeArrayFlatBufferNUMA(dsaY, setup->numBuffers);
@@ -1300,7 +1314,7 @@ EXPORT_SYMBOL(dsaPerform);
  *     and signed.
  *
  *****************************************************************************/
-CpaStatus dsaSignPerform(dsa_test_params_t *setup)
+static CpaStatus dsaSignPerform(dsa_test_params_t *setup)
 {
     Cpa32U i = 0;
     Cpa32U outerLoop = 0;
@@ -1743,7 +1757,7 @@ barrier:
  *     Print out the DSA performance
  *
  *****************************************************************************/
-CpaStatus dsaPrintStats(thread_creation_data_t *data)
+static CpaStatus dsaPrintStats(thread_creation_data_t *data)
 {
     PRINT("DSA VERIFY\n");
     PRINT("Modulus Size %19d\n", data->packetSize * NUM_BITS_IN_BYTE);
@@ -1760,7 +1774,7 @@ CpaStatus dsaPrintStats(thread_creation_data_t *data)
  *     Print out the DSA sign only performance
  *
  *****************************************************************************/
-CpaStatus dsaSignPrintStats(thread_creation_data_t *data)
+static CpaStatus dsaSignPrintStats(thread_creation_data_t *data)
 {
     PRINT("DSA SIGN\n");
     PRINT("Modulus Size %19d\n", data->packetSize * NUM_BITS_IN_BYTE);
@@ -1787,7 +1801,7 @@ static void dsaPerformanceGen(single_thread_test_data_t *testSetup,
     CpaInstanceHandle *cyInstances = NULL;
     CpaStatus status = CPA_STATUS_FAIL;
     dsa_test_params_t *params = (dsa_test_params_t *)testSetup->setupPtr;
-    CpaInstanceInfo2 instanceInfo = {0};
+    CpaInstanceInfo2 *instanceInfo = NULL;
 #ifdef SC_DEV_INFO_ENABLED
     CpaDeviceInfo deviceInfo = {0};
 #endif
@@ -1830,10 +1844,19 @@ static void dsaPerformanceGen(single_thread_test_data_t *testSetup,
         dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
         sampleCodeThreadExit();
     }
+    instanceInfo = qaeMemAlloc(sizeof(CpaInstanceInfo2));
+    if (instanceInfo == NULL)
+    {
+        PRINT_ERR("Failed to allocate memory for instanceInfo");
+        dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
+        sampleCodeThreadExit();
+    }
+    memset(instanceInfo, 0, sizeof(CpaInstanceInfo2));
     cyInstances = qaeMemAlloc(sizeof(CpaInstanceHandle) * numInstances);
     if (NULL == cyInstances)
     {
         PRINT_ERR("Could not allocate memory for logical instances\n");
+        qaeMemFree((void **)&instanceInfo);
         dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
         sampleCodeThreadExit();
     }
@@ -1843,23 +1866,26 @@ static void dsaPerformanceGen(single_thread_test_data_t *testSetup,
     dsaSetup.cyInstanceHandle =
         cyInstances[(testSetup->logicalQaInstance) % numInstances];
 
-    status = cpaCyInstanceGetInfo2(dsaSetup.cyInstanceHandle, &instanceInfo);
+    status = cpaCyInstanceGetInfo2(dsaSetup.cyInstanceHandle, instanceInfo);
     if (CPA_STATUS_SUCCESS != status)
     {
         PRINT_ERR("%s::%d cpaCyInstanceGetInfo2 failed", __func__, __LINE__);
         qaeMemFree((void **)&cyInstances);
+        qaeMemFree((void **)&instanceInfo);
         dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
         sampleCodeThreadExit();
     }
 
 #ifdef SC_DEV_INFO_ENABLED
     /* check whether asym service enabled or not for the instance */
-    status = cpaGetDeviceInfo(instanceInfo.physInstId.packageId, &deviceInfo);
+    status =
+        cpaGetDeviceInfo(instanceInfo->physInstId.acceleratorId, &deviceInfo);
     if (CPA_STATUS_SUCCESS != status)
     {
         PRINT_ERR("%s::%d cpaGetDeviceInfo failed", __func__, __LINE__);
         dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
         qaeMemFree((void **)&cyInstances);
+        qaeMemFree((void **)&instanceInfo);
         sampleCodeThreadExit();
     }
     if (CPA_FALSE == deviceInfo.cyAsymEnabled)
@@ -1870,14 +1896,15 @@ static void dsaPerformanceGen(single_thread_test_data_t *testSetup,
                   __LINE__);
         dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
         qaeMemFree((void **)&cyInstances);
+        qaeMemFree((void **)&instanceInfo);
         sampleCodeThreadExit();
     }
 #endif
-    if (instanceInfo.physInstId.packageId > packageIdCount_g)
+    if (instanceInfo->physInstId.packageId > packageIdCount_g)
     {
-        packageIdCount_g = instanceInfo.physInstId.packageId;
+        packageIdCount_g = instanceInfo->physInstId.packageId;
     }
-    dsaSetup.performanceStats->packageId = instanceInfo.physInstId.packageId;
+    dsaSetup.performanceStats->packageId = instanceInfo->physInstId.packageId;
 
 
     /*launch function that does all the work */
@@ -1900,6 +1927,7 @@ static void dsaPerformanceGen(single_thread_test_data_t *testSetup,
         dsaSetup.performanceStats->threadReturnStatus = CPA_STATUS_FAIL;
     }
     qaeMemFree((void **)&cyInstances);
+    qaeMemFree((void **)&instanceInfo);
     sampleCodeThreadComplete(testSetup->threadID);
 }
 
